#
# spec file for package aalib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aalib
%define lname	libaa1
Version:        1.4.0
Release:        515.1
Summary:        An ASCII Art Library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://aa-project.sourceforge.net/
Source:         http://sourceforge.net/projects/aa-project/files/aa-lib/1.4rc5/%{name}-1.4rc5.tar.gz
Source1:        http://downloads.sourceforge.net/project/aa-project/aavga/1.0rc1/aavga-1.0rc1.tar.gz
Source2:        http://downloads.sourceforge.net/project/aa-project/aview/1.3.0rc1/aview-1.3.0rc1.tar.gz
Source3:        baselibs.conf
Patch1:         fix_gpm_fd_handling.diff
Patch2:         aavga.dif
Patch3:         aalib-1.4.0.dif
Patch4:         aview-1.3.0.patch
Patch5:         aview-1.3.0-tmpvuln.diff
Patch6:         aalib-distint.patch
Patch7:         aview-signed-char.patch
Patch8:         aview-includes.patch
Patch9:         aalib-includes.patch
Patch10:        aalib-reentrant.patch
Patch11:        aalib-1.4.0-config.patch
Patch12:        aalib-1.4.0-fdleak.patch
Patch13:        aalib-ncurses-6.0-accessors.patch
BuildRequires:  fdupes
BuildRequires:  gpm-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig(x11)
PreReq:         %install_info_prereq
# bug437293
%ifarch ppc64
Obsoletes:      aalib-64bit
%endif

%description
AA-lib is a low level gfx library. AA-lib does not require a graphics
device. In fact, there is no graphical output possible. AA-lib replaces
old-fashioned output methods with a powerful ASCII art renderer.

%package -n %lname
Summary:        An ASCII Art Library
Group:          System/Libraries

%description -n %lname
AA-lib is a low level gfx library. AA-lib does not require a graphics
device. In fact, there is no graphical output possible. AA-lib replaces
old-fashioned output methods with a powerful ASCII art renderer.

%package devel
Summary:        Development Package for AAlib
Group:          Development/Libraries/C and C++
# bug437293
%ifarch ppc64
Obsoletes:      aalib-devel-64bit
%endif
Requires:       %lname = %version
Requires:       glibc-devel
Obsoletes:      aalibdev

%description devel
Files needed for developing software that uses AAlib.

%prep
%setup -q -a 1 -b 2
%patch -P 1
%patch -P 3
%patch -P 10
%patch -P 11
%patch -P 12
%patch -P 13 -p1
cd aavga-1.0
%patch -P 2
cd ../../aview-*
%patch -P 4
%patch -P 7
%patch -P 8
cd ..
%patch -P 5
%patch -P 6
%patch -P 9

%build
%{?suse_update_config}
autoreconf -fiv
export CFLAGS="%{optflags} -fstrength-reduce -fomit-frame-pointer -fpermissive"
%ifarch %ix86
export CFLAGS="$CFLAGS -falign-loops=2 -falign-jumps=2 -falign-functions=2"
%endif
%configure --disable-static --with-slang-driver=no --with-ncurses
%make_build

%install
%make_install
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}
cp -av ANNOUNCE AUTHORS COPYING INSTALL NEWS README %{buildroot}/%{_defaultdocdir}/%{name}
cd ../aview-1.3.0
PATH=%{buildroot}/%{_bindir}:$PATH \
   CFLAGS="%{optflags} -I%{buildroot}/usr/include" \
   LDFLAGS="-L%{buildroot}/%{_libdir}" \
   LD_LIBRARY_PATH="%{buildroot}/%{_libdir}" \
   ./configure --prefix=/usr --mandir=%{_mandir}
make
%make_install
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}/aview
cp -av README* ANNOUNCE COPYING TODO *.lsm %{buildroot}/%{_defaultdocdir}/%{name}/aview
cd -
cd aavga-1.0
make CFLAGS="%{optflags}"
cp -av aavga.so %{buildroot}/%_libdir
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}/aavga
cp -av aavga.lsm COPYING README %{buildroot}/%{_defaultdocdir}/%{name}/aavga
cd ..
rm -f %{buildroot}%{_libdir}/*.la
%fdupes %{buildroot}/%{_prefix}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%ldconfig_scriptlets -n %lname

%files
%docdir %{_defaultdocdir}/%{name}
%{_defaultdocdir}/%{name}
%_bindir/aafire
%_bindir/aaflip
%_bindir/aainfo
%_bindir/aasavefont
%_bindir/aatest
%_bindir/asciiview
%_bindir/aview
%{_infodir}/aalib.info.gz
%{_infodir}/aalib.info-?.gz
%{_mandir}/man1/aafire.1.gz
%{_mandir}/man1/aview.1.gz
%{_mandir}/man1/asciiview.1.gz

%files -n %lname
%_libdir/libaa.so.1.0.4
%_libdir/libaa.so.1
%_libdir/aavga.so

%files devel
%_includedir/aalib.h
%_libdir/libaa.so
%_datadir/aclocal/aalib.m4
%_bindir/aalib-config
%{_mandir}/man3/aa_*.3.gz
%{_mandir}/man3/mem_d.3.gz
%{_mandir}/man3/save_d.3.gz

%changelog
* Thu May  9 2024 Jan Engelhardt <jengelh@inai.de>
- Remove conditionals for SUSE 11.3
* Mon May  6 2024 Martin Jambor <mjambor@suse.com>
- Add -fpermissive to optflags (boo#1223910).
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Nov 15 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Homepage link http://aa-project.sourceforge.net/ is a permanent
  redirect to its HTTPS counterpart https://aa-project.sourceforge.net/
* Sun Sep 11 2022 Dirk Müller <dmueller@suse.com>
- avoid ffast-math (ggo#55522)
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static).
- Run fdupes, and trim old rpm constructs.
* Sat Oct 17 2015 meissner@suse.com
- aavga.dif: add -fno-stack-protector to shared aavga.so object build
* Wed Sep  9 2015 dimstar@opensuse.org
- Add aalib-ncurses-6.0-accessors.patch: Fix build with
  NCurses 6.0 with WINDOW_OPAQUE set to 1.
* Sun May 17 2015 meissner@suse.com
- info deinstall needs to be in preun section.
* Mon Sep 15 2014 crrodriguez@opensuse.org
- Use pkgconfig(x11) not metapackage xorg-x11-devel
* Fri Mar 22 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Mar 18 2013 mmeister@suse.com
- Replace Source with Link to source
* Sat Feb 11 2012 jengelh@medozas.de
- Strip distinct version from -devel subpackage
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Fri Sep 16 2011 jengelh@medozas.de
- Implement shlib policy
- Remove redundant tags; use %%_smp_mflags
* Mon Sep  5 2011 coolo@suse.com
- fix build with newer ld
* Tue Sep  7 2010 aj@suse.de
- BuildRequire gpm-devel
* Wed Jan 27 2010 jengelh@medozas.de
- package baselibs.conf
* Mon Oct  5 2009 crrodriguez@opensuse.org
- fix aalib-1.4.0-477.9: possible missing call to fclose [bnc#523344]
* Wed Apr 22 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies
- fix aalib-config so it only returns needed libraries
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Mar 29 2007 meissner@suse.de
- Buildrequires: gpm
* Fri Sep  8 2006 dmueller@suse.de
- explicitely disable slang driver
* Thu Sep  7 2006 mskibbe@suse.de
- fix compiler problems
- fix Requires lsit for devel package
* Fri Sep  1 2006 mskibbe@suse.de
- fix Requires
* Thu Aug 31 2006 dmueller@suse.de
- build against ncurses instead of slang
* Wed Aug 16 2006 aj@suse.de
- Remove unneeded BuildRequires.
* Wed May 17 2006 schwab@suse.de
- Avoid crash when resizing window with X driver.
* Mon Apr 10 2006 meissner@suse.de
- added requires slang-devel to aalib-devel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Thu Jul  7 2005 hvogel@suse.de
- fix some more decls
* Tue Jul  5 2005 hvogel@suse.de
- fix implicit functions
* Sun Jul  3 2005 hvogel@suse.de
- sign chars to make comparison work. Patch from olh (Bug #95092)
* Thu Jun 23 2005 hvogel@suse.de
- require exact aalib version
- add %%clean section
* Wed Jan 19 2005 hvogel@suse.de
- fix the uninitialized variables fix, NULL is for pointers, use 0
* Wed Jan 19 2005 hvogel@suse.de
- fix use of uninitialized variables
* Sat Oct 23 2004 hvogel@suse.de
- move config script to the devel package
* Tue Aug 31 2004 hvogel@suse.de
- remove insecure temp file creation in asciiview [Bug #44386]
* Mon Apr 19 2004 ro@suse.de
- fix "control reaches end of non-void function" warning
* Thu Jan 29 2004 hvogel@suse.de
- run ldconfig after install/deinstall
- mark man pages as documentation
* Mon Jan 26 2004 hvogel@suse.de
- move autoconf macro file to the devel subpackage
* Tue Jan 13 2004 schwab@suse.de
- Fix quoting in autoconf macros.
* Fri Jan  9 2004 kukuk@suse.de
- Fix underquoted definition of AM_PATH_AALIB in aalib.m4
* Tue Jul 29 2003 aj@suse.de
- Fix for chown change.
* Sun May 25 2003 ro@suse.de
- added man pages for mem_d and save_d to filelist
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Wed Apr 23 2003 coolo@suse.de
- use BuildRoot
* Fri Feb  7 2003 fehr@suse.de
- Use %%install_info macro
* Thu Feb  6 2003 fehr@suse.de
- add patch to link aavga lib also in systems with use lib64
* Tue Feb  4 2003 fehr@suse.de
- update to aalib-1.4rc5, aavga-1.0rc1, aview-1.3.0rc1
* Mon Dec  2 2002 fehr@suse.de
- fixed problem with new gcc/glibc
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Aug 14 2002 fehr@suse.de
- fix bug handling gmp_fd variable in aaslnkbd.c (#17426)
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Mon Jun 10 2002 meissner@suse.de
- copy over system auto* tools so we build on new platforms.
* Fri May 31 2002 ro@suse.de
- changed neededforbuild <slang> to <slang slang-devel>
* Wed Apr 24 2002 fehr@suse.de
- make it build on architectures with X11-libs in /usr/X11R6/lib64
* Wed Jan 30 2002 coolo@suse.de
- use %%_libdir
* Tue Jan 29 2002 nadvornik@suse.cz
- fixed initialization of slang library [bug #12933]
* Wed Aug 29 2001 fehr@suse.de
- add packages aview and aavga
* Thu Mar  1 2001 bk@suse.de
- add platform optimisation flags
- move suse_update_config to %%prep and move install to %%install
* Wed Jan 17 2001 schwab@suse.de
- Add Obsoletes: aalibdev to aalib-devel package.
- Move libaa.so to aalib-devel.
- Require aalib from aalib-devel package.
* Sat Dec  9 2000 nashif@suse.de
- Set the right Groups
- Changed package name: aalibdev -> aalib-devel
* Fri May 19 2000 fehr@suse.de
- move documentation to /usr/share/doc/packages
* Thu Mar 30 2000 schwab@suse.de
- Update config.{status,guess} from automake.
* Fri Feb 25 2000 kukuk@suse.de
- Move /usr/info -> /usr/share/info, add group tag
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jan 11 1999 fehr@suse.de
- make SuSE package from version 1.2 of aalib
